<?php
/**
 * Moony - the PHP simplistic framework
 *
 * @package   Moony
 * @author    YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @link      http://moony.sourceforge.jp/
 * @copyright 2005-2007 YAMAOKA Hiroyuki
 * @license   http://opensource.org/licenses/bsd-license.php The BSD License
 */

/**
 * アクションのルーティング処理を行います。
 *
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @access public
 */
class Moony_Router
{
    /**
     * アクションのルーティング処理を行います。
     * エントリポイントに渡されたPATH_INFOにしたがって、
     * 以下のような順番でアクションクラスの探索が行われます。
     *   - 「/foo/bar」の場合、「Foo_Bar」、「Foo」
     *   - 「/foo/bar/」の場合、「Foo_Bar_Index」、「Foo_Bar」、「Foo」
     *   - 「/」の場合、「Index」
     * アクションクラスが見つからなかった場合、nullを返します。
     *
     * @access public
     * @param object $request Moony_Requestのインスタンス
     * @param string $action_dir アクションクラスを格納するディレクトリ
     * @return object アクションクラスのインスタンス
     */
    function route(&$request, $action_dir)
    {
        $path_info = ltrim(strtolower($request->getPathInfo()), '/');
        if (strlen($path_info) == 0 || substr($path_info, -1, 1) == '/') {
            $path_info .= 'index';
        }

        $path_info_array = array_map('ucfirst', explode('/', $path_info));

        while (count($path_info_array) > 0) {

            $action_path = implode(DIRECTORY_SEPARATOR, $path_info_array);
            $action_name = implode('_', $path_info_array);

            if ($this->_load($action_name, $action_path, $action_dir)) {
                $action =& new $action_name;
                $request->setActionPath($action_path);
                return $action;
            }

            array_pop($path_info_array);
        }

        $request->setActionPath($path_info);
        return null;
    }

    /**
     * アクションクラスのローディングを試みます。
     *
     * @access protected
     * @param string $action_name アクション名（＝アクションクラス名）
     * @param string $action_path アクションパス
     * @param string $action_dir アクションクラスが格納されるディレクトリ
     * @return bool ローディングに成功すればtrue
     */
    function _load($action_name, $action_path, $action_dir)
    {
        $path = $action_dir . DIRECTORY_SEPARATOR . $action_path . '.php';
        if (file_exists($path)) {
            include_once $path;
            if (class_exists($action_name)) {
                return true;
            }
        }
        return false;
    }
}
?>
